import numpy as np
import scipy.linalg
from pyscf import gto, scf, dft, cc, mcscf
mol = gto.M(atom='H 0 0 0; F 0 0 1', basis='ccpvdz')

hcore = mol.intor('cint1e_kin_sph') + mol.intor('cint1e_nuc_sph')
s = mol.intor('cint1e_ovlp_sph')
nao = s.shape[0]
eri = mol.intor('cint2e_sph').reshape(nao,nao,nao,nao)
vhf = 0
nocc = mol.nelectron // 2
for cycle in range(30):
    fock = hcore + vhf
    e, c = scipy.linalg.eigh(fock, s)
    dm = np.dot(c[:,:nocc], c[:,:nocc].T) * 2
    j = np.einsum('ijkl,ij->kl', eri, dm)
    k = np.einsum('ijkl,jk->il', eri, dm)
    vhf = j - k * 0.5
    e_tot = np.einsum('ij,ij', hcore, dm) + np.einsum('ij,ij', vhf, dm) * .5
    print(cycle, e_tot + mol.energy_nuc())
                                    
